Changelog
=========

Version 0.1.2 [2017-07-22]
--------------------------

- `#13 <https://github.com/openwisp/openwisp-network-topology/issues/13>`_:
  Fixed the fetch and receive API bugs
- `#15 <https://github.com/openwisp/openwisp-network-topology/pull/15>`_:
  Imported admin tests from django-netjsongraph
- `#16 <https://github.com/openwisp/openwisp-network-topology/pull/16>`_:
  Added more tests by importing all from django-netjsongraph

Version 0.1.1 [2017-07-10]
--------------------------

- `95f8ade <https://github.com/openwisp/openwisp-network-topology/commit/95f8ade>`_: [admin] Moved submit_line.html to `openwisp-utils <https://github.com/openwisp/openwisp-utils>`_

Version 0.1 [2017-06-29]
------------------------

- Added multi-tenancy and integrated `django-netjsongraph <https://github.com/netjson/django-netjsongraph>`_
